@@ -306,6 +306,7 @@ class TerminalWindow(ScrollText):
         self.settag()
         self.listenthread=None
         self.connectString=""
+        self.stopping=False
 
     def settag(self):
         tagname = self.myfontcolor + ";" + self.mycolor
@@ -456,6 +457,7 @@ class TerminalWindow(ScrollText):
         self.sendtext("Connecting to %s %d\n" % (server,port))
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.socket.connect((server, port))
+        self.stopping=False
         self.listenthread = threading.Thread(target=self.doListen)
         self.listenthread.start()
         if (self.connectString!=""):
@@ -472,7 +474,11 @@ class TerminalWindow(ScrollText):
     def disconnect(self):
         print("Disconnecting...")
         try:
+            self.stopping=True
             self.socket.close()
+            if (self.listenthread!=None):
+                threading.join(self.listenthread)
+            self.listenthread=None
         except:
             pass
 
@@ -480,6 +486,9 @@ class TerminalWindow(ScrollText):
         try:
             while True:
                 (readlist,writelist,exceptlist)=select.select([self.socket],[],[],1) 
+                if self.stopping:
+                    print("Listen thread stopping.")
+                    break
                 if self.socket in readlist:
                     b = self.socket.recv(128)
                     self.sendtext(b.decode("utf-8"))
